@@ -3,6 +3,7 @@
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 import datetime
+from trytond.tools import safe_eval
 
 
 class Template(ModelSQL, ModelView):
@@ -105,7 +106,7 @@ class Product(ModelSQL, ModelView):
                 return False
             if operator == "=":
                 operator= "=="
-            res = res and (eval(str(value) + operator + str(operand)))
+            res = res and (safe_eval(str(value) + operator + str(operand)))
         return res
 
     def search_quantity(self, cursor, user, name, domain=None, context=None):
@@ -367,25 +368,36 @@ class Product(ModelSQL, ModelView):
             where_vals = args
         else:
             where_clause = " IN (" + \
-                ",".join(["%s" for i in location_ids]) + ") "
+                ",".join(('%s',) * len(location_ids)) + ") "
             where_vals = location_ids[:]
 
         if move_query:
             where_clause += " AND " + move_query + " "
             where_vals += move_val
 
+        product_template_join = ""
         if product_ids:
             where_clause += "AND product in (" + \
-                ",".join(["%s" for i in product_ids]) + ")"
+                ",".join(('%s',) * len(product_ids)) + ")"
             where_vals += product_ids
+        else:
+            where_clause += "AND product_template.active = %s"
+            where_vals.append(True)
+            product_template_join = \
+                    "JOIN product_product "\
+                        "ON (stock_move.product = product_product.id) "\
+                    "JOIN product_template "\
+                        "ON (product_product.template = "\
+                            "product_template.id) "\
+
 
         if context.get('stock_destinations'):
             destinations = context.get('stock_destinations')
             dest_clause_from = " AND from_location in ("
-            dest_clause_from += ",".join("%s" for i in destinations)
+            dest_clause_from += ",".join(('%s',) * len(destinations))
             dest_clause_from += ") "
             dest_clause_to = " AND to_location in ("
-            dest_clause_to += ",".join("%s" for i in destinations)
+            dest_clause_to += ",".join(('%s',) * len(destinations))
             dest_clause_to += ") "
             dest_vals = destinations
 
@@ -398,14 +410,14 @@ class Product(ModelSQL, ModelView):
                 "FROM ( "\
                     "SELECT to_location AS location, product, uom, "\
                         "sum(quantity) AS quantity "\
-                    "FROM stock_move "\
+                    "FROM stock_move " + product_template_join + \
                     "WHERE (%s) " \
                         "AND to_location %s "\
                     "GROUP BY to_location, product ,uom "\
                     "UNION  "\
                     "SELECT from_location AS location, product, uom, "\
                         "-sum(quantity) AS quantity "\
-                    "FROM stock_move "\
+                    "FROM stock_move " + product_template_join + \
                     "WHERE (%s) " \
                         "AND from_location %s "\
                     "GROUP BY from_location, product, uom "\
@@ -428,13 +440,10 @@ class Product(ModelSQL, ModelView):
                 if line[position] not in id_list:
                     id_list.append(line[position])
 
-        if not product_ids:
-            product_ids = self.pool.get("product.product").search(
-                cursor, user, [], context=context)
         uom_by_id = dict([(x.id, x) for x in uom_obj.browse(
                 cursor, user, uom_ids, context=context)])
         default_uom = dict((x.id, x.default_uom) for x in product_obj.browse(
-                cursor, user, product_ids, context=context))
+                cursor, user, product_ids or res_product_ids, context=context))
 
         for line in raw_lines:
             location, product, uom, quantity = line
@@ -487,7 +496,13 @@ class Product(ModelSQL, ModelView):
 
         # Complete result with missing products if asked
         if not skip_zero:
-            keys = ((l,p) for l in location_ids for p in product_ids)
+            # Search for all products, even if not linked with moves
+            if product_ids:
+                all_product_ids = product_ids
+            else:
+                all_product_ids = self.pool.get("product.product").search(
+                    cursor, user, [], context=context)
+            keys = ((l,p) for l in location_ids for p in all_product_ids)
             for location_id, product_id in keys:
                 if (location_id, product_id) not in res:
                     res[(location_id, product_id)] = 0.0
@@ -513,7 +528,7 @@ class Product(ModelSQL, ModelView):
         location_obj = self.pool.get('stock.location')
         locations = location_obj.browse(cursor, user, context.get('locations'),
                                         context=context)
-        return value + " (" + ",".join([l.name for l in locations]) + ")"
+        return value + " (" + ",".join(l.name for l in locations) + ")"
 
 Product()
 
